;; Generated package description from gpr-query.el  -*- no-byte-compile: t -*-
(define-package "gpr-query" "1.0.3.0.20230128.112055" "Minor mode for navigating sources using gpr_query" '((emacs "25.3") (wisi "4.2.2") (gnat-compiler "1.0.2")) :commit "ada0d0afcefe88b66b9cc53de5d76db661bfb2d7" :url "https://elpa.gnu.org/packages/gpr-query.html" :authors '(("Stephen Leake" . "stephen_leake@member.fsf.org")) :maintainer '("Stephen Leake" . "stephen_leake@member.fsf.org"))
